@@ -25,7 +25,7 @@
 #' library(googledrive)
 #' library(googlesheets4)
 #' drive_auth(email = "jane_doe@example.com")
-#' sheets_auth(token = drive_token())
+#' gs4_auth(token = drive_token())
 #' # work with both packages freely now
 #' ```
 #'
@@ -62,12 +62,12 @@ credentials_byo_oauth2 <- function(scopes = NULL, token, ...) {
   token
 }
 
-check_endpoint <- function(endpoint) {
+check_endpoint <- function(endpoint, call = caller_env()) {
   stopifnot(inherits(endpoint, "oauth_endpoint"))
   urls <- endpoint[c("authorize", "access", "validate", "revoke")]
   urls_ok <- all(grepl("google", urls))
   if (!urls_ok) {
-    gargle_abort("Token doesn't use Google's OAuth endpoint")
+    gargle_abort("Token doesn't use Google's OAuth endpoint.", call = call)
   }
   endpoint
 }
